
\! echo "INSTALLATION FOOTBALL DATABASE AND TABELES";
\! echo "IMPLEMENT BY : REZA.AHMADI";

DROP DATABASE IF EXISTS `football_db`;
CREATE DATABASE `football_db` ;
USE football_db;

CREATE TABLE IF NOT EXISTS TEAM(
    t_name VARCHAR(32),
    color VARCHAR(16),
    city VARCHAR(32),
    PRIMARY KEY(t_name)
    );

CREATE TABLE IF NOT EXISTS PLAYER (
    id_card INT AUTO_INCREMENT,
    first_name VARCHAR(32) NOT NULL,
    last_name VARCHAR(32) NOT NULL,
    p_num TINYINT,
    t_name VARCHAR(32),
    d_from DATE,
    d_to DATE,
    PRIMARY KEY(id_card),
    FOREIGN KEY(t_name) REFERENCES TEAM(t_name)
    );

CREATE TABLE IF NOT EXISTS PERSONNEL(
    f_code INT AUTO_INCREMENT,
    first_name VARCHAR(32),
    last_name VARCHAR(32),
    p_role VARCHAR(32),
    PRIMARY KEY(f_code)
    );

CREATE TABLE IF NOT EXISTS Have(
    t_name VARCHAR(32),
    per_f_code INT,
    d_from DATE,
    d_to DATE,
    FOREIGN KEY(t_name) REFERENCES TEAM(t_name),
    FOREIGN KEY(per_f_code) REFERENCES PERSONNEL(f_code),
    CONSTRAINT pk_have PRIMARY KEY(t_name,per_f_code,d_from)
    );

CREATE TABLE IF NOT EXISTS GAME (
    game_id INT AUTO_INCREMENT,
    t1_name VARCHAR(32),
    t2_name VARCHAR(32),
    date_time DATETIME,
    t1_goals TINYINT,
    t2_goals TINYINT,
    stadium VARCHAR(32),
    PRIMARY KEY(game_id),
    FOREIGN KEY (t1_name) REFERENCES TEAM(t_name),
    FOREIGN KEY (t2_name) REFERENCES TEAM(t_name)
    );

CREATE TABLE IF NOT EXISTS Play(
    p_id_card INT,
    game_id INT,
    goals TINYINT,
    yellow_card TINYINT,
    red_card BOOLEAN,
    FOREIGN KEY (p_id_card) REFERENCES PLAYER(id_card),
    FOREIGN KEY (game_id) REFERENCES GAME(game_id),
    CONSTRAINT pk_play PRIMARY KEY(p_id_card,game_id)
    );

CREATE TABLE IF NOT EXISTS REFEREE(
    ref_id INT AUTO_INCREMENT,
    first_name VARCHAR(32),
    last_name VARCHAR(32),
    PRIMARY KEY(ref_id)
    );

CREATE TABLE IF NOT EXISTS Judges(
    game_id INT,
    ref_id INT,
    position TINYINT,
    FOREIGN KEY (game_id) REFERENCES GAME(game_id),
    FOREIGN KEY (ref_id) REFERENCES REFEREE(ref_id),
    CONSTRAINT pk_judges PRIMARY KEY(game_id,ref_id)
    );

\! echo "INSTALLATION END! :)";

